@@ -1,6 +1,6 @@
 from django.conf import settings
 from django.core.management import BaseCommand
-from entity_subscription.models import Source
+from entity_event.models import Source, SourceGroup
 
 from entity_emailer.utils import constants
 from entity_emailer.models import EmailTemplate
@@ -14,11 +14,20 @@ class Command(BaseCommand):
         admin_template_name = getattr(
             settings, 'ENTITY_EMAILER_ADMIN_TEMPLATE_NAME', constants['default_admin_template_name']
         )
+        source_group = SourceGroup.objects.get_or_create(
+            name=admin_source_name,
+            defaults={
+                'display_name': admin_source_name,
+                'description': 'Admin notifications.',
+            }
+        )[0]
         Source.objects.get_or_create(
             name=admin_source_name,
-            display_name=admin_source_name,
-            description='Admin notifications.',
-        )
+            defaults={
+                'group': source_group,
+                'display_name': admin_source_name,
+                'description': 'Admin notifications.',
+            })
         EmailTemplate.objects.get_or_create(
             template_name=admin_template_name,
             html_template='{{ html|safe }}',
